# constant, reserved keywords
RESERVES=["alias", "all", "config", "node", "bucket", "lb", "dbaas", "create", "get", "list", "update", "edit", "delete", "file", "doc", "help", "default"]

#version
packagke_version="e2e-cli/1.0.0 Python Linux/Mac/Windows"

#package_info
packagke_info=" A command line tool developed by E2E Networks Ltd. \r\n Used to access and manage my_account/e2e_cloud services from cmd/shell \r\n Published 1st April 2023"

#url for api request
BASE_URL="https://api.e2enetworks.com/"


# for better error handeling, write --action options here for argparser
